# Sponsors

The following organisations and individuals supported the [Wagtail's First Hatch](https://www.kickstarter.com/projects/noripyt/wagtails-first-hatch) crowdfunding campaign:

- [Springload](https://springload.nz/)
- [NetFM](https://netfm.org/)
- [Ambient Innovation](https://ambient-innovation.com/)
- [Shenberger Technology](http://shenbergertech.com/)
- [Type/Code](https://typecode.com/)
- [SharperTool](https://sharpertool.com/)
- [Overcast Software](https://www.overcast.io/)
- [Octave](https://octave.nz/)
- [Taywa](https://www.taywa.ch/)
- [Rock Kitchen Harris](https://www.rkh.co.uk/)
- [The Motley Fool](https://www.fool.com/)
- [R Strother Scott](https://twitter.com/rstrotherscott)
- [Beyond Media](https://www.beyond.works/)
